<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_Preconnect
 * @copyright   Pinpoint
 * @author
 */

namespace Pinpoint\Preconnect\Observer\Framework\View\Layout;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\View\Page\Config as PageConfig;
use Magento\Store\Model\ScopeInterface;

class Builder implements ObserverInterface
{
    private const PRECONNECT_TYPE = 'preconnect';
    private const PRECONNECT_CONFIG = 'general/pinpoint/preconnect_sites';
    /** @var PageConfig $pageConfig */
    private PageConfig $pageConfig;
    /**
     * @var ScopeConfigInterface
     */
    private ScopeConfigInterface $scopeConfig;

    /**
     * Builder constructor.
     * @param PageConfig $pageConfig
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(
        PageConfig           $pageConfig,
        ScopeConfigInterface $scopeConfig
    ) {
        $this->pageConfig = $pageConfig;
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * @param Observer $observer
     * @return $this
     */
    public function execute(Observer $observer)
    {
        try {
            $urls = $this->scopeConfig->getValue(self::PRECONNECT_CONFIG, ScopeInterface::SCOPE_STORE);
            $urls = json_decode($urls, true);
            if (!empty($urls) && is_array($urls)) {
                foreach ($urls as $resource) {
                    $this->pageConfig->addRemotePageAsset($resource['preconnect_url'],
                        'link_rel',
                        ['attributes' => ['rel' => self::PRECONNECT_TYPE]]
                    );
                }
            }
        } catch (\Exception $e) {}
        return $this;
    }
}
